==> seedsui-react-5.5.1.tgz: package/es/DatePicker/RangeCombo/index.js <==
var _excluded = ["separator", "caption", "min", "max", "type", "format", "ranges", "onError", "ModalProps", "value"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

// require PrototypeDate.js和PrototypeString.js
import React, { forwardRef, useImperativeHandle, useRef } from 'react';
import Combo from './../../Picker/Combo';
import Modal from './../RangeModal';
import Utils from './Utils';
import locale from './../../locale';
var RangeCombo = forwardRef(function (_ref, ref) {
  var _ref2;

  var separator = _ref.separator,
      caption = _ref.caption,
      min = _ref.min,
      max = _ref.max,
      type = _ref.type,
      format = _ref.format,
      _ref$ranges = _ref.ranges,
      ranges = _ref$ranges === void 0 ? (_ref2 = {}, _ref2[locale('今天', 'datepicker-tooltip_today')] = [new Date(), new Date()], _ref2[locale('昨天', 'datepicker-tooltip_yesterday')] = [new Date().prevDate(), new Date().prevDate()], _ref2[locale('本月', 'datepicker-tooltip_this_month')] = [new Date().firstMonthDate(), new Date()], _ref2[locale('上月', 'datepicker-tooltip_last_month')] = [new Date().prevMonth().firstMonthDate(), new Date().prevMonth().lastMonthDate()], _ref2[locale('最近7天', 'datepicker-tooltip_last_days', ['7'])] = [new Date().prevDate(7), new Date()], _ref2[locale('最近30天', 'datepicker-tooltip_last_days', ['30'])] = [new Date().prevDate(30), new Date()], _ref2[locale('自定义时间', 'datepicker-tooltip_custom_date')] = 90, _ref2) : _ref$ranges,
      onError = _ref.onError,
      _ref$ModalProps = _ref.ModalProps,
      ModalProps = _ref$ModalProps === void 0 ? {} : _ref$ModalProps,
      value = _ref.value,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  var rootRef = useRef(null);
  var instance = useRef(null);
  useImperativeHandle(ref, function () {
    var _rootRef$current, _rootRef$current2;

    return {
      getRootDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current = rootRef.current) === null || _rootRef$current === void 0 ? void 0 : _rootRef$current.getRootDOM,
      getModalDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current2 = rootRef.current) === null || _rootRef$current2 === void 0 ? void 0 : _rootRef$current2.getModalDOM,
      getInstance: function getInstance() {
        return instance.current;
      }
    };
  }); // 实例化

  instance.current = {
    getDisplayValue: function getDisplayValue(value) {
      return Utils.getDisplayValue({
        type: type,
        format: format,
        separator: separator,
        value: value
      });
    }
  }; // 显示值

  var displayValue = instance.current.getDisplayValue(value);
  return /*#__PURE__*/React.createElement(Combo, _extends({
    ref: rootRef,
    value: displayValue,
    ModalComponent: Modal,
    ModalProps: _extends({
      separator: separator,
      caption: caption,
      value: value,
      min: min,
      max: max,
      type: type,
      ranges: ranges,
      onError: onError
    }, ModalProps)
  }, props));
});
export default RangeCombo;

==> seedsui-react-5.5.3.tgz: package/es/DatePicker/RangeCombo/index.js <==
var _excluded = ["separator", "caption", "min", "max", "type", "format", "ranges", "daysLimit", "onError", "ModalProps", "value"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

// require PrototypeDate.js和PrototypeString.js
import React, { forwardRef, useImperativeHandle, useRef } from 'react';
import Combo from './../../Picker/Combo';
import Modal from './../RangeModal';
import Utils from './Utils';
import locale from './../../locale';
var RangeCombo = forwardRef(function (_ref, ref) {
  var _locale, _ref2;

  var separator = _ref.separator,
      caption = _ref.caption,
      min = _ref.min,
      max = _ref.max,
      type = _ref.type,
      format = _ref.format,
      _ref$ranges = _ref.ranges,
      ranges = _ref$ranges === void 0 ? (_ref2 = {}, _ref2[locale('今天', 'datepicker-tooltip_today')] = [new Date(), new Date()], _ref2[locale('昨天', 'datepicker-tooltip_yesterday')] = [new Date().prevDate(), new Date().prevDate()], _ref2[locale('本月', 'datepicker-tooltip_this_month')] = [new Date().firstMonthDate(), new Date()], _ref2[locale('上月', 'datepicker-tooltip_last_month')] = [new Date().prevMonth().firstMonthDate(), new Date().prevMonth().lastMonthDate()], _ref2[locale('最近7天', 'datepicker-tooltip_last_days', ['7'])] = [new Date().prevDate(7), new Date()], _ref2[locale('最近30天', 'datepicker-tooltip_last_days', ['30'])] = [new Date().prevDate(30), new Date()], _ref2[locale('自定义时间', 'datepicker-tooltip_custom_date')] = (_locale = {}, _locale[locale('自定义时间', 'datepicker-tooltip_custom_date')] = null, _locale), _ref2) : _ref$ranges,
      daysLimit = _ref.daysLimit,
      onError = _ref.onError,
      _ref$ModalProps = _ref.ModalProps,
      ModalProps = _ref$ModalProps === void 0 ? {} : _ref$ModalProps,
      value = _ref.value,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  var rootRef = useRef(null);
  var instance = useRef(null);
  useImperativeHandle(ref, function () {
    var _rootRef$current, _rootRef$current2;

    return {
      getRootDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current = rootRef.current) === null || _rootRef$current === void 0 ? void 0 : _rootRef$current.getRootDOM,
      getModalDOM: rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current2 = rootRef.current) === null || _rootRef$current2 === void 0 ? void 0 : _rootRef$current2.getModalDOM,
      getInstance: function getInstance() {
        return instance.current;
      }
    };
  }); // 实例化

  instance.current = {
    getDisplayValue: function getDisplayValue(value) {
      return Utils.getDisplayValue({
        type: type,
        format: format,
        separator: separator,
        value: value
      });
    }
  }; // 显示值

  var displayValue = instance.current.getDisplayValue(value);
  return /*#__PURE__*/React.createElement(Combo, _extends({
    ref: rootRef,
    value: displayValue,
    ModalComponent: Modal,
    ModalProps: _extends({
      separator: separator,
      caption: caption,
      value: value,
      min: min,
      max: max,
      type: type,
      ranges: ranges,
      daysLimit: daysLimit,
      onError: onError
    }, ModalProps)
  }, props));
});
export default RangeCombo;
